@@ -11,5 +11,5 @@ coords = symbols("t x y z", real=True)
 variables = ()
 functions = symbols("alpha beta", cls=Function)
 t, x, y, z = coords
-al, be = functions
-metric = diag(-1, exp(2 * be(t)), exp(2 * be(t)), exp(2 * al(t)))
+alpha, beta = functions
+metric = diag(-1, exp(2 * beta(t)), exp(2 * beta(t)), exp(2 * alpha(t)))
