@@ -12,5 +12,5 @@ coords = symbols("t r theta phi", real=True)
 variables = ()
 functions = symbols("alpha beta", cls=Function)
 t, r, th, ph = coords
-al, be = functions
-metric = diag(-exp(2 * al(r)), exp(2 * be(r)), r ** 2, r ** 2 * sin(th) ** 2)
+alpha, beta = functions
+metric = diag(-exp(2 * alpha(r)), exp(2 * beta(r)), r ** 2, r ** 2 * sin(th) ** 2)
